==> devextreme-21.1.1-alpha-21089-0329.tgz: package/renovation/ui/scroll_view/bottom_pocket.js <==
/**
 * DevExtreme (renovation/ui/scroll_view/bottom_pocket.js)
 * Version: 21.1.0 (build 21089-0329)
 * Build date: Tue Mar 30 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.BottomPocket = exports.viewFunction = void 0;
var _inferno = require("inferno");
var _base_component = require("devextreme-generator/modules/inferno/base_component");
var _type = require("../../../core/utils/type");
var _scrollable_utils = require("./scrollable_utils");
var _message = _interopRequireDefault(require("../../../localization/message"));
var _bottom_pocket_props = require("./bottom_pocket_props");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var SCROLLVIEW_REACHBOTTOM_CLASS = "dx-scrollview-scrollbottom";
var SCROLLVIEW_REACHBOTTOM_INDICATOR_CLASS = "dx-scrollview-scrollbottom-indicator";
var SCROLLVIEW_REACHBOTTOM_TEXT_CLASS = "dx-scrollview-scrollbottom-text";
var viewFunction = function(viewModel) {
    var reachBottomText = viewModel.reachBottomText;
    return (0, _inferno.createVNode)(1, "div", _scrollable_utils.SCROLLVIEW_BOTTOM_POCKET_CLASS, (0, _inferno.createVNode)(1, "div", SCROLLVIEW_REACHBOTTOM_CLASS, [(0, _inferno.createVNode)(1, "div", SCROLLVIEW_REACHBOTTOM_INDICATOR_CLASS), (0, _inferno.createVNode)(1, "div", SCROLLVIEW_REACHBOTTOM_TEXT_CLASS, (0, _inferno.createVNode)(1, "div", null, reachBottomText, 0), 2)], 4), 2)
};
exports.viewFunction = viewFunction;
var BottomPocket = function(_BaseInfernoComponent) {
    _inheritsLoose(BottomPocket, _BaseInfernoComponent);

    function BottomPocket(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {};
        return _this
    }
    var _proto = BottomPocket.prototype;
    _proto.render = function() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            reachBottomText: this.reachBottomText,
            restAttributes: this.restAttributes
        })
    };
    _createClass(BottomPocket, [{
        key: "reachBottomText",
        get: function() {
            var reachBottomText = this.props.reachBottomText;
            if ((0, _type.isDefined)(reachBottomText)) {
                return reachBottomText
            }
            return _message.default.format("dxScrollView-reachBottomText")
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props = this.props,
                restProps = (_this$props.reachBottomText, _objectWithoutProperties(_this$props, ["reachBottomText"]));
            return restProps
        }
    }]);
    return BottomPocket
}(_base_component.BaseInfernoComponent);
exports.BottomPocket = BottomPocket;
BottomPocket.defaultProps = _extends({}, _bottom_pocket_props.BottomPocketProps);

==> devextreme-21.2.1-alpha-21212-0323.tgz: package/renovation/ui/scroll_view/bottom_pocket.js <==
/**
 * DevExtreme (renovation/ui/scroll_view/bottom_pocket.js)
 * Version: 21.2.0 (build 21212-0323)
 * Build date: Sat Jul 31 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.BottomPocket = exports.BottomPocketPropsType = exports.BottomPocketProps = exports.viewFunction = void 0;
var _inferno = require("inferno");
var _vdom = require("@devextreme/vdom");
var _load_indicator = require("../load_indicator");
var _type = require("../../../core/utils/type");
var _consts = require("./common/consts");
var _message = _interopRequireDefault(require("../../../localization/message"));
var _base_props = require("../common/base_props");
var _combine_classes = require("../../utils/combine_classes");
var _excluded = ["bottomPocketRef", "reachBottomText", "visible"];

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _objectWithoutProperties(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = _objectWithoutPropertiesLoose(source, excluded);
    var key, i;
    if (Object.getOwnPropertySymbols) {
        var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
        for (i = 0; i < sourceSymbolKeys.length; i++) {
            key = sourceSymbolKeys[i];
            if (excluded.indexOf(key) >= 0) {
                continue
            }
            if (!Object.prototype.propertyIsEnumerable.call(source, key)) {
                continue
            }
            target[key] = source[key]
        }
    }
    return target
}

function _objectWithoutPropertiesLoose(source, excluded) {
    if (null == source) {
        return {}
    }
    var target = {};
    var sourceKeys = Object.keys(source);
    var key, i;
    for (i = 0; i < sourceKeys.length; i++) {
        key = sourceKeys[i];
        if (excluded.indexOf(key) >= 0) {
            continue
        }
        target[key] = source[key]
    }
    return target
}

function _defineProperty(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        })
    } else {
        obj[key] = value
    }
    return obj
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) {
            descriptor.writable = true
        }
        Object.defineProperty(target, descriptor.key, descriptor)
    }
}

function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) {
        _defineProperties(Constructor.prototype, protoProps)
    }
    if (staticProps) {
        _defineProperties(Constructor, staticProps)
    }
    return Constructor
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var viewFunction = function(viewModel) {
    var bottomPocketRef = viewModel.props.bottomPocketRef,
        reachBottomClasses = viewModel.reachBottomClasses,
        reachBottomText = viewModel.reachBottomText;
    return (0, _inferno.createVNode)(1, "div", _consts.SCROLLVIEW_BOTTOM_POCKET_CLASS, (0, _inferno.createVNode)(1, "div", reachBottomClasses, [(0, _inferno.createVNode)(1, "div", _consts.SCROLLVIEW_REACHBOTTOM_INDICATOR_CLASS, (0, _inferno.createComponentVNode)(2, _load_indicator.LoadIndicator), 2), (0, _inferno.createVNode)(1, "div", _consts.SCROLLVIEW_REACHBOTTOM_TEXT_CLASS, (0, _inferno.createVNode)(1, "div", null, reachBottomText, 0), 2)], 4), 2, null, null, bottomPocketRef)
};
exports.viewFunction = viewFunction;
var BottomPocketProps = {};
exports.BottomPocketProps = BottomPocketProps;
var BottomPocketPropsType = {
    visible: _base_props.BaseWidgetProps.visible
};
exports.BottomPocketPropsType = BottomPocketPropsType;
var BottomPocket = function(_BaseInfernoComponent) {
    _inheritsLoose(BottomPocket, _BaseInfernoComponent);

    function BottomPocket(props) {
        var _this;
        _this = _BaseInfernoComponent.call(this, props) || this;
        _this.state = {};
        return _this
    }
    var _proto = BottomPocket.prototype;
    _proto.render = function() {
        var props = this.props;
        return viewFunction({
            props: _extends({}, props),
            reachBottomText: this.reachBottomText,
            reachBottomClasses: this.reachBottomClasses,
            restAttributes: this.restAttributes
        })
    };
    _createClass(BottomPocket, [{
        key: "reachBottomText",
        get: function() {
            var reachBottomText = this.props.reachBottomText;
            if ((0, _type.isDefined)(reachBottomText)) {
                return reachBottomText
            }
            return _message.default.format("dxScrollView-reachBottomText")
        }
    }, {
        key: "reachBottomClasses",
        get: function() {
            var _classesMap;
            var visible = this.props.visible;
            var classesMap = (_classesMap = {}, _defineProperty(_classesMap, _consts.SCROLLVIEW_REACHBOTTOM_CLASS, true), _defineProperty(_classesMap, "dx-state-invisible", !visible), _classesMap);
            return (0, _combine_classes.combineClasses)(classesMap)
        }
    }, {
        key: "restAttributes",
        get: function() {
            var _this$props = this.props,
                restProps = (_this$props.bottomPocketRef, _this$props.reachBottomText, _this$props.visible, _objectWithoutProperties(_this$props, _excluded));
            return restProps
        }
    }]);
    return BottomPocket
}(_vdom.BaseInfernoComponent);
exports.BottomPocket = BottomPocket;
BottomPocket.defaultProps = _extends({}, BottomPocketPropsType);
